@@ -7,7 +7,7 @@ package Bio::Graphics::Browser2::TrackDumper;
 #
 ###################################################################
 
-# $Id: TrackDumper.pm 23185 2010-05-12 19:53:06Z lstein $
+# $Id: TrackDumper.pm 23222 2010-05-17 14:47:51Z lstein $
 
 # Simple track dumper, suitable for a lightweight replacement to DAS.
 # Call this way:
@@ -31,7 +31,7 @@ use Bio::Graphics::Browser2;
 use Bio::Graphics::FeatureFile;
 use Bio::Graphics::Browser2::RegionSearch;
 use Bio::Graphics::Browser2::Shellwords;
-
+use Bio::Graphics::Browser2::Util 'modperl_request';
 sub new {
     my $class   = shift;
     my %options = @_;
@@ -135,11 +135,50 @@ sub dump_sam {
     $key        ||= $label;
 
     my $header = $db->header;
+
     print $header->text;
     print "\@C0\t$key\n";
     print "\@C0\tGenerated by GBrowse from ",$self->origin($label),"\n";
     print "\@C0\tSequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
 
+    # there are problems with the filehandle-based conversion of 
+    # BAM to TAM because the low-level functions write to STDOUT directly
+    # which are munged in modperl and fastcgi environments.
+
+    # in the case of modperl, we revert to doing the conversion at the perl level
+    # which may be slower
+    if (modperl_request()) {
+	if (Bio::DB::Bam::AlignWrapper->can('tam_line')) {
+	    my $iterator = $db->features(@args,-iterator=>1);
+	    print $_->tam_line,"\n" while $_ = $iterator->next_seq;
+	} else {
+	    print "## Bio::DB::SamTools 1.19 or higher required for printing SAM data when running under mod_perl\n";
+	}
+	return;
+    }
+
+
+    # With FastCGI, we can handle this by piping the result to ourselves.
+    if (Bio::Graphics::Browser2::Render->fcgi_request()) {
+	eval "use IO::Pipe" unless IO::Pipe->can('new');
+	my $pipe = IO::Pipe->new;
+	my $child = Bio::Graphics::Browser2::Render->fork();
+	if ($child) {
+	    $pipe->reader();
+	    print while <$pipe>;
+	} else {
+	    $pipe->writer();
+	    my $fh = $db->features(@args,-fh  => 1);
+	    while (<$fh>) {
+		warn $_;
+		print $pipe $_ ;
+	    }
+	    exit 0;
+	}
+	return;
+    }
+
+    # CGI scripts simply do it directly.
     my $fh = $db->features(@args,-fh  => 1);
     print while <$fh>;
 }
@@ -437,7 +476,6 @@ sub guess_file_type {
     # so if multiple tracks are selected, we default to the
     # common gff3 format. In the future, we should create a
     # TAR file for download.
-    warn "labels = ",join ',',@$labels;
     if (@$labels > 1) {  
 	return 'gff3';
     }
@@ -446,8 +484,6 @@ sub guess_file_type {
     my $glyph = $source->setting(      $label => 'glyph');
     my $db    = $source->open_database($label);
 
-    warn "db = $db";
-
     if ($glyph && $glyph =~ /wiggle/) {
 	return 'bed';
     }
